zip

# XMLRésuméLibrary: User Guide

year | Element Reference | XSL Parameter Reference

## Name

zip — A zip code

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `zip` element contains a single zip code (United States postal code). It may contain any format, such as standard five-digit (“34525”), ZIP+4 (“34525-1625”), or any other valid format.

For non-U.S. postal codes, use `postalCode`.

### Parents

`zip` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify a zip code. The zip code may then be referred to by this identifier.

## See Also

`postalCode`.

## Examples

For examples, see `address`.

year | Element Reference | XSL Parameter Reference